Struct MixerConfig
pub struct MixerConfig {
pub min_delay: Duration,
pub delay_range: Duration,
pub capacity: usize,
pub metric_delay_window: u64,
}Expand description
Mixer configuration.
Fields
min_delay: DurationThe minimum delay introduced during mixing.
delay_range: DurationThe range from the minimum delay to the maximum possible delay.
capacity: usizeThe capacity of the preallocated mixer buffer.
It is possible to insert more items past the capacity, triggering a possible buffer reallocation.
metric_delay_window: u64Implementations
impl MixerConfig
impl MixerConfig
pub fn random_delay(&self) -> Duration
pub fn random_delay(&self) -> Duration
Get a random delay duration from the specified minimum and maximum delay available inside the configuration.